# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .get_installation_template import *
from .get_installation_templates import *
from .get_server import *
from .get_servers import *
from .get_vrack_networks import *
from .provider import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_ovh.cloud as __cloud
    cloud = __cloud
    import pulumi_ovh.cloudproject as __cloudproject
    cloudproject = __cloudproject
    import pulumi_ovh.cloudprojectdatabase as __cloudprojectdatabase
    cloudprojectdatabase = __cloudprojectdatabase
    import pulumi_ovh.config as __config
    config = __config
    import pulumi_ovh.dbaas as __dbaas
    dbaas = __dbaas
    import pulumi_ovh.dedicated as __dedicated
    dedicated = __dedicated
    import pulumi_ovh.domain as __domain
    domain = __domain
    import pulumi_ovh.hosting as __hosting
    hosting = __hosting
    import pulumi_ovh.iam as __iam
    iam = __iam
    import pulumi_ovh.ip as __ip
    ip = __ip
    import pulumi_ovh.iploadbalancing as __iploadbalancing
    iploadbalancing = __iploadbalancing
    import pulumi_ovh.me as __me
    me = __me
    import pulumi_ovh.okms as __okms
    okms = __okms
    import pulumi_ovh.order as __order
    order = __order
    import pulumi_ovh.ovhcloud as __ovhcloud
    ovhcloud = __ovhcloud
    import pulumi_ovh.savingsplan as __savingsplan
    savingsplan = __savingsplan
    import pulumi_ovh.vmware as __vmware
    vmware = __vmware
    import pulumi_ovh.vps as __vps
    vps = __vps
    import pulumi_ovh.vrack as __vrack
    vrack = __vrack
else:
    cloud = _utilities.lazy_import('pulumi_ovh.cloud')
    cloudproject = _utilities.lazy_import('pulumi_ovh.cloudproject')
    cloudprojectdatabase = _utilities.lazy_import('pulumi_ovh.cloudprojectdatabase')
    config = _utilities.lazy_import('pulumi_ovh.config')
    dbaas = _utilities.lazy_import('pulumi_ovh.dbaas')
    dedicated = _utilities.lazy_import('pulumi_ovh.dedicated')
    domain = _utilities.lazy_import('pulumi_ovh.domain')
    hosting = _utilities.lazy_import('pulumi_ovh.hosting')
    iam = _utilities.lazy_import('pulumi_ovh.iam')
    ip = _utilities.lazy_import('pulumi_ovh.ip')
    iploadbalancing = _utilities.lazy_import('pulumi_ovh.iploadbalancing')
    me = _utilities.lazy_import('pulumi_ovh.me')
    okms = _utilities.lazy_import('pulumi_ovh.okms')
    order = _utilities.lazy_import('pulumi_ovh.order')
    ovhcloud = _utilities.lazy_import('pulumi_ovh.ovhcloud')
    savingsplan = _utilities.lazy_import('pulumi_ovh.savingsplan')
    vmware = _utilities.lazy_import('pulumi_ovh.vmware')
    vps = _utilities.lazy_import('pulumi_ovh.vps')
    vrack = _utilities.lazy_import('pulumi_ovh.vrack')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "ovh",
  "mod": "CloudProject/alerting",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/alerting:Alerting": "Alerting"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistry",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistry:ContainerRegistry": "ContainerRegistry"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryIPRestrictionsManagement",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryIPRestrictionsManagement:ContainerRegistryIPRestrictionsManagement": "ContainerRegistryIPRestrictionsManagement"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryIPRestrictionsRegistry",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryIPRestrictionsRegistry:ContainerRegistryIPRestrictionsRegistry": "ContainerRegistryIPRestrictionsRegistry"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryOIDC",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryOIDC:ContainerRegistryOIDC": "ContainerRegistryOIDC"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryUser",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryUser:ContainerRegistryUser": "ContainerRegistryUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/database",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/database:Database": "Database"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/failoverIpAttach",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/failoverIpAttach:FailoverIpAttach": "FailoverIpAttach"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/gateway",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/gatewayInterface",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/gatewayInterface:GatewayInterface": "GatewayInterface"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/instance",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/instanceSnapshot",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/instanceSnapshot:InstanceSnapshot": "InstanceSnapshot"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kube",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kube:Kube": "Kube"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kubeIpRestrictions",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kubeIpRestrictions:KubeIpRestrictions": "KubeIpRestrictions"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kubeNodePool",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kubeNodePool:KubeNodePool": "KubeNodePool"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kubeOidc",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kubeOidc:KubeOidc": "KubeOidc"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/loadBalancer",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/networkPrivate",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/networkPrivate:NetworkPrivate": "NetworkPrivate"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/networkPrivateSubnet",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/networkPrivateSubnet:NetworkPrivateSubnet": "NetworkPrivateSubnet"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/networkPrivateSubnetV2",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/networkPrivateSubnetV2:NetworkPrivateSubnetV2": "NetworkPrivateSubnetV2"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/project",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/project:Project": "Project"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/rancher",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/rancher:Rancher": "Rancher"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/regionLoadBalancerLogSubscription",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/regionLoadBalancerLogSubscription:RegionLoadBalancerLogSubscription": "RegionLoadBalancerLogSubscription"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/regionNetwork",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/regionNetwork:RegionNetwork": "RegionNetwork"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/regionStoragePresign",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/regionStoragePresign:RegionStoragePresign": "RegionStoragePresign"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/s3Credential",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/s3Credential:S3Credential": "S3Credential"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/s3Policy",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/s3Policy:S3Policy": "S3Policy"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/storage",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/storage:Storage": "Storage"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/user",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/user:User": "User"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/volume",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/volumeBackup",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/volumeBackup:VolumeBackup": "VolumeBackup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/workflowBackup",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/workflowBackup:WorkflowBackup": "WorkflowBackup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/databaseInstance",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/integration",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/ipRestriction",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/ipRestriction:IpRestriction": "IpRestriction"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/kafkaAcl",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/kafkaAcl:KafkaAcl": "KafkaAcl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/kafkaSchemaRegistryAcl",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/kafkaSchemaRegistryAcl:KafkaSchemaRegistryAcl": "KafkaSchemaRegistryAcl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/kafkaTopic",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/kafkaTopic:KafkaTopic": "KafkaTopic"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/logSubscription",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/logSubscription:LogSubscription": "LogSubscription"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/m3DbNamespace",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/m3DbNamespace:M3DbNamespace": "M3DbNamespace"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/m3DbUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/m3DbUser:M3DbUser": "M3DbUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/mongoDbPrometheus",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/mongoDbPrometheus:MongoDbPrometheus": "MongoDbPrometheus"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/mongoDbUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/mongoDbUser:MongoDbUser": "MongoDbUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/opensearchPattern",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/opensearchPattern:OpensearchPattern": "OpensearchPattern"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/opensearchUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/opensearchUser:OpensearchUser": "OpensearchUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/postgresSqlConnectionPool",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/postgresSqlConnectionPool:PostgresSqlConnectionPool": "PostgresSqlConnectionPool"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/postgresSqlUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/postgresSqlUser:PostgresSqlUser": "PostgresSqlUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/prometheus",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/prometheus:Prometheus": "Prometheus"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/redisUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/redisUser:RedisUser": "RedisUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/user",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/user:User": "User"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsCluster",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsCluster:LogsCluster": "LogsCluster"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsInput",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsInput:LogsInput": "LogsInput"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsOutputGraylogStream",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsOutputGraylogStream:LogsOutputGraylogStream": "LogsOutputGraylogStream"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsOutputOpenSearchAlias",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsOutputOpenSearchAlias:LogsOutputOpenSearchAlias": "LogsOutputOpenSearchAlias"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsOutputOpenSearchIndex",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsOutputOpenSearchIndex:LogsOutputOpenSearchIndex": "LogsOutputOpenSearchIndex"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsRole",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsRole:LogsRole": "LogsRole"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsRolePermissionStream",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsRolePermissionStream:LogsRolePermissionStream": "LogsRolePermissionStream"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsToken",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsToken:LogsToken": "LogsToken"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/cephAcl",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/cephAcl:CephAcl": "CephAcl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/nasHAPartition",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/nasHAPartition:NasHAPartition": "NasHAPartition"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/nasHAPartitionAccess",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/nasHAPartitionAccess:NasHAPartitionAccess": "NasHAPartitionAccess"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/nasHAPartitionSnapshot",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/nasHAPartitionSnapshot:NasHAPartitionSnapshot": "NasHAPartitionSnapshot"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/server",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/server:Server": "Server"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverNetworking",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverNetworking:ServerNetworking": "ServerNetworking"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverRebootTask",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverRebootTask:ServerRebootTask": "ServerRebootTask"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverReinstallTask",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverReinstallTask:ServerReinstallTask": "ServerReinstallTask"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverUpdate",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverUpdate:ServerUpdate": "ServerUpdate"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/dSRecords",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/dSRecords:DSRecords": "DSRecords"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/name",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/name:Name": "Name"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/nameServers",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/nameServers:NameServers": "NameServers"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zone",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneDNSSec",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneDNSSec:ZoneDNSSec": "ZoneDNSSec"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneImport",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneImport:ZoneImport": "ZoneImport"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneRecord",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneRecord:ZoneRecord": "ZoneRecord"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneRedirection",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneRedirection:ZoneRedirection": "ZoneRedirection"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabase",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabase:PrivateDatabase": "PrivateDatabase"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseAllowlist",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseAllowlist:PrivateDatabaseAllowlist": "PrivateDatabaseAllowlist"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseDb",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseDb:PrivateDatabaseDb": "PrivateDatabaseDb"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseUser",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseUser:PrivateDatabaseUser": "PrivateDatabaseUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseUserGrant",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseUserGrant:PrivateDatabaseUserGrant": "PrivateDatabaseUserGrant"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Iam/permissionsGroup",
  "fqn": "pulumi_ovh.iam",
  "classes": {
   "ovh:Iam/permissionsGroup:PermissionsGroup": "PermissionsGroup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Iam/policy",
  "fqn": "pulumi_ovh.iam",
  "classes": {
   "ovh:Iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Iam/resourceGroup",
  "fqn": "pulumi_ovh.iam",
  "classes": {
   "ovh:Iam/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/firewall",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/firewallRule",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/ipService",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/ipService:IpService": "IpService"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/mitigation",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/mitigation:Mitigation": "Mitigation"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/move",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/move:Move": "Move"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/reverse",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/reverse:Reverse": "Reverse"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpFarm",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpFarm:HttpFarm": "HttpFarm"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpFarmServer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpFarmServer:HttpFarmServer": "HttpFarmServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpFrontend",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpFrontend:HttpFrontend": "HttpFrontend"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpRoute",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpRoute:HttpRoute": "HttpRoute"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpRouteRule",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpRouteRule:HttpRouteRule": "HttpRouteRule"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/loadBalancer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/refresh",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/refresh:Refresh": "Refresh"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/ssl",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/ssl:Ssl": "Ssl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpFarm",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpFarm:TcpFarm": "TcpFarm"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpFarmServer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpFarmServer:TcpFarmServer": "TcpFarmServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpFrontend",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpFrontend:TcpFrontend": "TcpFrontend"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpRoute",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpRoute:TcpRoute": "TcpRoute"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpRouteRule",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpRouteRule:TcpRouteRule": "TcpRouteRule"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/udpFarm",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/udpFarm:UdpFarm": "UdpFarm"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/udpFarmServer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/udpFarmServer:UdpFarmServer": "UdpFarmServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/udpFrontend",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/udpFrontend:UdpFrontend": "UdpFrontend"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/vrackNetwork",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/vrackNetwork:VrackNetwork": "VrackNetwork"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Me/aPIOAuth2Client",
  "fqn": "pulumi_ovh.me",
  "classes": {
   "ovh:Me/aPIOAuth2Client:APIOAuth2Client": "APIOAuth2Client"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Me/identityGroup",
  "fqn": "pulumi_ovh.me",
  "classes": {
   "ovh:Me/identityGroup:IdentityGroup": "IdentityGroup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Me/identityUser",
  "fqn": "pulumi_ovh.me",
  "classes": {
   "ovh:Me/identityUser:IdentityUser": "IdentityUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/credential",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/credential:Credential": "Credential"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/okms",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/okms:Okms": "Okms"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/serviceKey",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/serviceKey:ServiceKey": "ServiceKey"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/serviceKeyJWK",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/serviceKeyJWK:ServiceKeyJWK": "ServiceKeyJWK"
  }
 },
 {
  "pkg": "ovh",
  "mod": "SavingsPlan/savingsPlan",
  "fqn": "pulumi_ovh.savingsplan",
  "classes": {
   "ovh:SavingsPlan/savingsPlan:SavingsPlan": "SavingsPlan"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vps/vps",
  "fqn": "pulumi_ovh.vps",
  "classes": {
   "ovh:Vps/vps:Vps": "Vps"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/cloudProject",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/cloudProject:CloudProject": "CloudProject"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/dedicatedServer",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/dedicatedServer:DedicatedServer": "DedicatedServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/dedicatedServerInterface",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/dedicatedServerInterface:DedicatedServerInterface": "DedicatedServerInterface"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/ipAddress",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/ipAddress:IpAddress": "IpAddress"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/ipLoadbalancing",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/ipLoadbalancing:IpLoadbalancing": "IpLoadbalancing"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/ipV6",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/ipV6:IpV6": "IpV6"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/oVHcloudConnect",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/oVHcloudConnect:OVHcloudConnect": "OVHcloudConnect"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/vrack",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/vrack:Vrack": "Vrack"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/vrackDedicatedCloud",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/vrackDedicatedCloud:VrackDedicatedCloud": "VrackDedicatedCloud"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/vrackservices",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/vrackservices:Vrackservices": "Vrackservices"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "ovh",
  "token": "pulumi:providers:ovh",
  "fqn": "pulumi_ovh",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetKafkaUserAccessResult',
    'AwaitableGetKafkaUserAccessResult',
    'get_kafka_user_access',
    'get_kafka_user_access_output',
]

@pulumi.output_type
class GetKafkaUserAccessResult:
    """
    A collection of values returned by getKafkaUserAccess.
    """
    def __init__(__self__, cert=None, cluster_id=None, id=None, key=None, service_name=None, user_id=None):
        if cert and not isinstance(cert, str):
            raise TypeError("Expected argument 'cert' to be a str")
        pulumi.set(__self__, "cert", cert)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def cert(self) -> builtins.str:
        """
        User cert.
        """
        return pulumi.get(self, "cert")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        (Sensitive) User key for the cert.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetKafkaUserAccessResult(GetKafkaUserAccessResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKafkaUserAccessResult(
            cert=self.cert,
            cluster_id=self.cluster_id,
            id=self.id,
            key=self.key,
            service_name=self.service_name,
            user_id=self.user_id)


def get_kafka_user_access(cluster_id: Optional[builtins.str] = None,
                          service_name: Optional[builtins.str] = None,
                          user_id: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKafkaUserAccessResult:
    """
    Use this data source to get information about user acces of a kafka cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    access = ovh.CloudProjectDatabase.get_kafka_user_access(service_name="XXX",
        cluster_id="YYY",
        user_id="ZZZ")
    pulumi.export("accessCert", access.cert)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: User ID
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getKafkaUserAccess:getKafkaUserAccess', __args__, opts=opts, typ=GetKafkaUserAccessResult).value

    return AwaitableGetKafkaUserAccessResult(
        cert=pulumi.get(__ret__, 'cert'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        key=pulumi.get(__ret__, 'key'),
        service_name=pulumi.get(__ret__, 'service_name'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_kafka_user_access_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKafkaUserAccessResult]:
    """
    Use this data source to get information about user acces of a kafka cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    access = ovh.CloudProjectDatabase.get_kafka_user_access(service_name="XXX",
        cluster_id="YYY",
        user_id="ZZZ")
    pulumi.export("accessCert", access.cert)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: User ID
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getKafkaUserAccess:getKafkaUserAccess', __args__, opts=opts, typ=GetKafkaUserAccessResult)
    return __ret__.apply(lambda __response__: GetKafkaUserAccessResult(
        cert=pulumi.get(__response__, 'cert'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        key=pulumi.get(__response__, 'key'),
        service_name=pulumi.get(__response__, 'service_name'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPaymentmeanCreditCardResult',
    'AwaitableGetPaymentmeanCreditCardResult',
    'get_paymentmean_credit_card',
    'get_paymentmean_credit_card_output',
]

@pulumi.output_type
class GetPaymentmeanCreditCardResult:
    """
    A collection of values returned by getPaymentmeanCreditCard.
    """
    def __init__(__self__, default=None, description=None, description_regexp=None, id=None, state=None, states=None, use_default=None, use_last_to_expire=None):
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if description_regexp and not isinstance(description_regexp, str):
            raise TypeError("Expected argument 'description_regexp' to be a str")
        pulumi.set(__self__, "description_regexp", description_regexp)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if states and not isinstance(states, list):
            raise TypeError("Expected argument 'states' to be a list")
        pulumi.set(__self__, "states", states)
        if use_default and not isinstance(use_default, bool):
            raise TypeError("Expected argument 'use_default' to be a bool")
        pulumi.set(__self__, "use_default", use_default)
        if use_last_to_expire and not isinstance(use_last_to_expire, bool):
            raise TypeError("Expected argument 'use_last_to_expire' to be a bool")
        pulumi.set(__self__, "use_last_to_expire", use_last_to_expire)

    @property
    @pulumi.getter
    def default(self) -> builtins.bool:
        """
        a boolean which tells if the retrieved credit card is marked as the default payment mean
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        the description attribute of the credit card
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="descriptionRegexp")
    def description_regexp(self) -> Optional[builtins.str]:
        return pulumi.get(self, "description_regexp")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        the state attribute of the credit card
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def states(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "states")

    @property
    @pulumi.getter(name="useDefault")
    def use_default(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "use_default")

    @property
    @pulumi.getter(name="useLastToExpire")
    def use_last_to_expire(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "use_last_to_expire")


class AwaitableGetPaymentmeanCreditCardResult(GetPaymentmeanCreditCardResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPaymentmeanCreditCardResult(
            default=self.default,
            description=self.description,
            description_regexp=self.description_regexp,
            id=self.id,
            state=self.state,
            states=self.states,
            use_default=self.use_default,
            use_last_to_expire=self.use_last_to_expire)


def get_paymentmean_credit_card(description_regexp: Optional[builtins.str] = None,
                                states: Optional[Sequence[builtins.str]] = None,
                                use_default: Optional[builtins.bool] = None,
                                use_last_to_expire: Optional[builtins.bool] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPaymentmeanCreditCardResult:
    """
    Use this data source to retrieve information about a credit card payment mean associated with an OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    cc = ovh.Me.get_paymentmean_credit_card(use_default=True)
    ```


    :param builtins.str description_regexp: a regexp used to filter credit cards on their `description` attributes.
    :param Sequence[builtins.str] states: Filter credit cards on their `state` attribute. Can be "expired", "valid", "tooManyFailures"
    :param builtins.bool use_default: Retrieve credit card marked as default payment mean.
    :param builtins.bool use_last_to_expire: Retrieve the credit card that will be the last to expire according to its expiration date.
    """
    __args__ = dict()
    __args__['descriptionRegexp'] = description_regexp
    __args__['states'] = states
    __args__['useDefault'] = use_default
    __args__['useLastToExpire'] = use_last_to_expire
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getPaymentmeanCreditCard:getPaymentmeanCreditCard', __args__, opts=opts, typ=GetPaymentmeanCreditCardResult).value

    return AwaitableGetPaymentmeanCreditCardResult(
        default=pulumi.get(__ret__, 'default'),
        description=pulumi.get(__ret__, 'description'),
        description_regexp=pulumi.get(__ret__, 'description_regexp'),
        id=pulumi.get(__ret__, 'id'),
        state=pulumi.get(__ret__, 'state'),
        states=pulumi.get(__ret__, 'states'),
        use_default=pulumi.get(__ret__, 'use_default'),
        use_last_to_expire=pulumi.get(__ret__, 'use_last_to_expire'))
def get_paymentmean_credit_card_output(description_regexp: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       states: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                       use_default: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                       use_last_to_expire: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPaymentmeanCreditCardResult]:
    """
    Use this data source to retrieve information about a credit card payment mean associated with an OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    cc = ovh.Me.get_paymentmean_credit_card(use_default=True)
    ```


    :param builtins.str description_regexp: a regexp used to filter credit cards on their `description` attributes.
    :param Sequence[builtins.str] states: Filter credit cards on their `state` attribute. Can be "expired", "valid", "tooManyFailures"
    :param builtins.bool use_default: Retrieve credit card marked as default payment mean.
    :param builtins.bool use_last_to_expire: Retrieve the credit card that will be the last to expire according to its expiration date.
    """
    __args__ = dict()
    __args__['descriptionRegexp'] = description_regexp
    __args__['states'] = states
    __args__['useDefault'] = use_default
    __args__['useLastToExpire'] = use_last_to_expire
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getPaymentmeanCreditCard:getPaymentmeanCreditCard', __args__, opts=opts, typ=GetPaymentmeanCreditCardResult)
    return __ret__.apply(lambda __response__: GetPaymentmeanCreditCardResult(
        default=pulumi.get(__response__, 'default'),
        description=pulumi.get(__response__, 'description'),
        description_regexp=pulumi.get(__response__, 'description_regexp'),
        id=pulumi.get(__response__, 'id'),
        state=pulumi.get(__response__, 'state'),
        states=pulumi.get(__response__, 'states'),
        use_default=pulumi.get(__response__, 'use_default'),
        use_last_to_expire=pulumi.get(__response__, 'use_last_to_expire')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetVracksResult',
    'AwaitableGetVracksResult',
    'get_vracks',
    'get_vracks_output',
]

@pulumi.output_type
class GetVracksResult:
    """
    A collection of values returned by getVracks.
    """
    def __init__(__self__, id=None, results=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if results and not isinstance(results, list):
            raise TypeError("Expected argument 'results' to be a list")
        pulumi.set(__self__, "results", results)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def results(self) -> Sequence[builtins.str]:
        """
        The list of vrack service name available for your OVHcloud account.
        """
        return pulumi.get(self, "results")


class AwaitableGetVracksResult(GetVracksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVracksResult(
            id=self.id,
            results=self.results)


def get_vracks(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVracksResult:
    """
    Use this data source to get the list of Vrack IDs available for your OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    vracks = ovh.Vrack.get_vracks()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Vrack/getVracks:getVracks', __args__, opts=opts, typ=GetVracksResult).value

    return AwaitableGetVracksResult(
        id=pulumi.get(__ret__, 'id'),
        results=pulumi.get(__ret__, 'results'))
def get_vracks_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVracksResult]:
    """
    Use this data source to get the list of Vrack IDs available for your OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    vracks = ovh.Vrack.get_vracks()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Vrack/getVracks:getVracks', __args__, opts=opts, typ=GetVracksResult)
    return __ret__.apply(lambda __response__: GetVracksResult(
        id=pulumi.get(__response__, 'id'),
        results=pulumi.get(__response__, 'results')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LogsOutputGraylogStreamArgs', 'LogsOutputGraylogStream']

@pulumi.input_type
class LogsOutputGraylogStreamArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 title: pulumi.Input[builtins.str],
                 cold_storage_compression: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_content: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_retention: Optional[pulumi.Input[builtins.int]] = None,
                 cold_storage_target: Optional[pulumi.Input[builtins.str]] = None,
                 indexing_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 indexing_max_size: Optional[pulumi.Input[builtins.int]] = None,
                 indexing_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 parent_stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 pause_indexing_on_max_size: Optional[pulumi.Input[builtins.bool]] = None,
                 retention_id: Optional[pulumi.Input[builtins.str]] = None,
                 web_socket_enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a LogsOutputGraylogStream resource.
        :param pulumi.Input[builtins.str] description: Stream description
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] title: Stream description
        :param pulumi.Input[builtins.str] cold_storage_compression: Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        :param pulumi.Input[builtins.str] cold_storage_content: ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        :param pulumi.Input[builtins.bool] cold_storage_enabled: Is Cold storage enabled?
        :param pulumi.Input[builtins.bool] cold_storage_notify_enabled: Notify on new Cold storage archive
        :param pulumi.Input[builtins.int] cold_storage_retention: Cold storage retention in year
        :param pulumi.Input[builtins.str] cold_storage_target: ColdStorage destination. One of "PCA", "PCS"
        :param pulumi.Input[builtins.bool] indexing_enabled: Enable ES indexing
        :param pulumi.Input[builtins.int] indexing_max_size: Maximum indexing size (in GB)
        :param pulumi.Input[builtins.bool] indexing_notify_enabled: If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        :param pulumi.Input[builtins.str] parent_stream_id: Parent stream ID
        :param pulumi.Input[builtins.bool] pause_indexing_on_max_size: If set, pause indexing when maximum size is reach
        :param pulumi.Input[builtins.str] retention_id: Retention ID
        :param pulumi.Input[builtins.bool] web_socket_enabled: Enable Websocket
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "title", title)
        if cold_storage_compression is not None:
            pulumi.set(__self__, "cold_storage_compression", cold_storage_compression)
        if cold_storage_content is not None:
            pulumi.set(__self__, "cold_storage_content", cold_storage_content)
        if cold_storage_enabled is not None:
            pulumi.set(__self__, "cold_storage_enabled", cold_storage_enabled)
        if cold_storage_notify_enabled is not None:
            pulumi.set(__self__, "cold_storage_notify_enabled", cold_storage_notify_enabled)
        if cold_storage_retention is not None:
            pulumi.set(__self__, "cold_storage_retention", cold_storage_retention)
        if cold_storage_target is not None:
            pulumi.set(__self__, "cold_storage_target", cold_storage_target)
        if indexing_enabled is not None:
            pulumi.set(__self__, "indexing_enabled", indexing_enabled)
        if indexing_max_size is not None:
            pulumi.set(__self__, "indexing_max_size", indexing_max_size)
        if indexing_notify_enabled is not None:
            pulumi.set(__self__, "indexing_notify_enabled", indexing_notify_enabled)
        if parent_stream_id is not None:
            pulumi.set(__self__, "parent_stream_id", parent_stream_id)
        if pause_indexing_on_max_size is not None:
            pulumi.set(__self__, "pause_indexing_on_max_size", pause_indexing_on_max_size)
        if retention_id is not None:
            pulumi.set(__self__, "retention_id", retention_id)
        if web_socket_enabled is not None:
            pulumi.set(__self__, "web_socket_enabled", web_socket_enabled)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        Stream description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[builtins.str]:
        """
        Stream description
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="coldStorageCompression")
    def cold_storage_compression(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        """
        return pulumi.get(self, "cold_storage_compression")

    @cold_storage_compression.setter
    def cold_storage_compression(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cold_storage_compression", value)

    @property
    @pulumi.getter(name="coldStorageContent")
    def cold_storage_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        """
        return pulumi.get(self, "cold_storage_content")

    @cold_storage_content.setter
    def cold_storage_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cold_storage_content", value)

    @property
    @pulumi.getter(name="coldStorageEnabled")
    def cold_storage_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is Cold storage enabled?
        """
        return pulumi.get(self, "cold_storage_enabled")

    @cold_storage_enabled.setter
    def cold_storage_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cold_storage_enabled", value)

    @property
    @pulumi.getter(name="coldStorageNotifyEnabled")
    def cold_storage_notify_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Notify on new Cold storage archive
        """
        return pulumi.get(self, "cold_storage_notify_enabled")

    @cold_storage_notify_enabled.setter
    def cold_storage_notify_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cold_storage_notify_enabled", value)

    @property
    @pulumi.getter(name="coldStorageRetention")
    def cold_storage_retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Cold storage retention in year
        """
        return pulumi.get(self, "cold_storage_retention")

    @cold_storage_retention.setter
    def cold_storage_retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cold_storage_retention", value)

    @property
    @pulumi.getter(name="coldStorageTarget")
    def cold_storage_target(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ColdStorage destination. One of "PCA", "PCS"
        """
        return pulumi.get(self, "cold_storage_target")

    @cold_storage_target.setter
    def cold_storage_target(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cold_storage_target", value)

    @property
    @pulumi.getter(name="indexingEnabled")
    def indexing_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable ES indexing
        """
        return pulumi.get(self, "indexing_enabled")

    @indexing_enabled.setter
    def indexing_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "indexing_enabled", value)

    @property
    @pulumi.getter(name="indexingMaxSize")
    def indexing_max_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum indexing size (in GB)
        """
        return pulumi.get(self, "indexing_max_size")

    @indexing_max_size.setter
    def indexing_max_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "indexing_max_size", value)

    @property
    @pulumi.getter(name="indexingNotifyEnabled")
    def indexing_notify_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        """
        return pulumi.get(self, "indexing_notify_enabled")

    @indexing_notify_enabled.setter
    def indexing_notify_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "indexing_notify_enabled", value)

    @property
    @pulumi.getter(name="parentStreamId")
    def parent_stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Parent stream ID
        """
        return pulumi.get(self, "parent_stream_id")

    @parent_stream_id.setter
    def parent_stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_stream_id", value)

    @property
    @pulumi.getter(name="pauseIndexingOnMaxSize")
    def pause_indexing_on_max_size(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        If set, pause indexing when maximum size is reach
        """
        return pulumi.get(self, "pause_indexing_on_max_size")

    @pause_indexing_on_max_size.setter
    def pause_indexing_on_max_size(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pause_indexing_on_max_size", value)

    @property
    @pulumi.getter(name="retentionId")
    def retention_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Retention ID
        """
        return pulumi.get(self, "retention_id")

    @retention_id.setter
    def retention_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_id", value)

    @property
    @pulumi.getter(name="webSocketEnabled")
    def web_socket_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable Websocket
        """
        return pulumi.get(self, "web_socket_enabled")

    @web_socket_enabled.setter
    def web_socket_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "web_socket_enabled", value)


@pulumi.input_type
class _LogsOutputGraylogStreamState:
    def __init__(__self__, *,
                 can_alert: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_compression: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_content: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_retention: Optional[pulumi.Input[builtins.int]] = None,
                 cold_storage_target: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 indexing_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 indexing_max_size: Optional[pulumi.Input[builtins.int]] = None,
                 indexing_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 is_editable: Optional[pulumi.Input[builtins.bool]] = None,
                 is_shareable: Optional[pulumi.Input[builtins.bool]] = None,
                 nb_alert_condition: Optional[pulumi.Input[builtins.int]] = None,
                 nb_archive: Optional[pulumi.Input[builtins.int]] = None,
                 parent_stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 pause_indexing_on_max_size: Optional[pulumi.Input[builtins.bool]] = None,
                 retention_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 web_socket_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 write_token: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogsOutputGraylogStream resources.
        :param pulumi.Input[builtins.bool] can_alert: Indicates if the current user can create alert on the stream
        :param pulumi.Input[builtins.str] cold_storage_compression: Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        :param pulumi.Input[builtins.str] cold_storage_content: ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        :param pulumi.Input[builtins.bool] cold_storage_enabled: Is Cold storage enabled?
        :param pulumi.Input[builtins.bool] cold_storage_notify_enabled: Notify on new Cold storage archive
        :param pulumi.Input[builtins.int] cold_storage_retention: Cold storage retention in year
        :param pulumi.Input[builtins.str] cold_storage_target: ColdStorage destination. One of "PCA", "PCS"
        :param pulumi.Input[builtins.str] created_at: Stream creation
        :param pulumi.Input[builtins.str] description: Stream description
        :param pulumi.Input[builtins.bool] indexing_enabled: Enable ES indexing
        :param pulumi.Input[builtins.int] indexing_max_size: Maximum indexing size (in GB)
        :param pulumi.Input[builtins.bool] indexing_notify_enabled: If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        :param pulumi.Input[builtins.bool] is_editable: Indicates if you are allowed to edit entry
        :param pulumi.Input[builtins.bool] is_shareable: Indicates if you are allowed to share entry
        :param pulumi.Input[builtins.int] nb_alert_condition: Number of alert condition
        :param pulumi.Input[builtins.int] nb_archive: Number of coldstored archivesr
        :param pulumi.Input[builtins.str] parent_stream_id: Parent stream ID
        :param pulumi.Input[builtins.bool] pause_indexing_on_max_size: If set, pause indexing when maximum size is reach
        :param pulumi.Input[builtins.str] retention_id: Retention ID
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] stream_id: Stream ID
        :param pulumi.Input[builtins.str] title: Stream description
        :param pulumi.Input[builtins.str] updated_at: Stream last updater
        :param pulumi.Input[builtins.bool] web_socket_enabled: Enable Websocket
        :param pulumi.Input[builtins.str] write_token: Write token of the stream (empty if the caller is not the owner of the stream)
        """
        if can_alert is not None:
            pulumi.set(__self__, "can_alert", can_alert)
        if cold_storage_compression is not None:
            pulumi.set(__self__, "cold_storage_compression", cold_storage_compression)
        if cold_storage_content is not None:
            pulumi.set(__self__, "cold_storage_content", cold_storage_content)
        if cold_storage_enabled is not None:
            pulumi.set(__self__, "cold_storage_enabled", cold_storage_enabled)
        if cold_storage_notify_enabled is not None:
            pulumi.set(__self__, "cold_storage_notify_enabled", cold_storage_notify_enabled)
        if cold_storage_retention is not None:
            pulumi.set(__self__, "cold_storage_retention", cold_storage_retention)
        if cold_storage_target is not None:
            pulumi.set(__self__, "cold_storage_target", cold_storage_target)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if indexing_enabled is not None:
            pulumi.set(__self__, "indexing_enabled", indexing_enabled)
        if indexing_max_size is not None:
            pulumi.set(__self__, "indexing_max_size", indexing_max_size)
        if indexing_notify_enabled is not None:
            pulumi.set(__self__, "indexing_notify_enabled", indexing_notify_enabled)
        if is_editable is not None:
            pulumi.set(__self__, "is_editable", is_editable)
        if is_shareable is not None:
            pulumi.set(__self__, "is_shareable", is_shareable)
        if nb_alert_condition is not None:
            pulumi.set(__self__, "nb_alert_condition", nb_alert_condition)
        if nb_archive is not None:
            pulumi.set(__self__, "nb_archive", nb_archive)
        if parent_stream_id is not None:
            pulumi.set(__self__, "parent_stream_id", parent_stream_id)
        if pause_indexing_on_max_size is not None:
            pulumi.set(__self__, "pause_indexing_on_max_size", pause_indexing_on_max_size)
        if retention_id is not None:
            pulumi.set(__self__, "retention_id", retention_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if stream_id is not None:
            pulumi.set(__self__, "stream_id", stream_id)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if web_socket_enabled is not None:
            pulumi.set(__self__, "web_socket_enabled", web_socket_enabled)
        if write_token is not None:
            pulumi.set(__self__, "write_token", write_token)

    @property
    @pulumi.getter(name="canAlert")
    def can_alert(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates if the current user can create alert on the stream
        """
        return pulumi.get(self, "can_alert")

    @can_alert.setter
    def can_alert(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "can_alert", value)

    @property
    @pulumi.getter(name="coldStorageCompression")
    def cold_storage_compression(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        """
        return pulumi.get(self, "cold_storage_compression")

    @cold_storage_compression.setter
    def cold_storage_compression(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cold_storage_compression", value)

    @property
    @pulumi.getter(name="coldStorageContent")
    def cold_storage_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        """
        return pulumi.get(self, "cold_storage_content")

    @cold_storage_content.setter
    def cold_storage_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cold_storage_content", value)

    @property
    @pulumi.getter(name="coldStorageEnabled")
    def cold_storage_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is Cold storage enabled?
        """
        return pulumi.get(self, "cold_storage_enabled")

    @cold_storage_enabled.setter
    def cold_storage_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cold_storage_enabled", value)

    @property
    @pulumi.getter(name="coldStorageNotifyEnabled")
    def cold_storage_notify_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Notify on new Cold storage archive
        """
        return pulumi.get(self, "cold_storage_notify_enabled")

    @cold_storage_notify_enabled.setter
    def cold_storage_notify_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cold_storage_notify_enabled", value)

    @property
    @pulumi.getter(name="coldStorageRetention")
    def cold_storage_retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Cold storage retention in year
        """
        return pulumi.get(self, "cold_storage_retention")

    @cold_storage_retention.setter
    def cold_storage_retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cold_storage_retention", value)

    @property
    @pulumi.getter(name="coldStorageTarget")
    def cold_storage_target(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ColdStorage destination. One of "PCA", "PCS"
        """
        return pulumi.get(self, "cold_storage_target")

    @cold_storage_target.setter
    def cold_storage_target(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cold_storage_target", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream creation
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="indexingEnabled")
    def indexing_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable ES indexing
        """
        return pulumi.get(self, "indexing_enabled")

    @indexing_enabled.setter
    def indexing_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "indexing_enabled", value)

    @property
    @pulumi.getter(name="indexingMaxSize")
    def indexing_max_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum indexing size (in GB)
        """
        return pulumi.get(self, "indexing_max_size")

    @indexing_max_size.setter
    def indexing_max_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "indexing_max_size", value)

    @property
    @pulumi.getter(name="indexingNotifyEnabled")
    def indexing_notify_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        """
        return pulumi.get(self, "indexing_notify_enabled")

    @indexing_notify_enabled.setter
    def indexing_notify_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "indexing_notify_enabled", value)

    @property
    @pulumi.getter(name="isEditable")
    def is_editable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates if you are allowed to edit entry
        """
        return pulumi.get(self, "is_editable")

    @is_editable.setter
    def is_editable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_editable", value)

    @property
    @pulumi.getter(name="isShareable")
    def is_shareable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates if you are allowed to share entry
        """
        return pulumi.get(self, "is_shareable")

    @is_shareable.setter
    def is_shareable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_shareable", value)

    @property
    @pulumi.getter(name="nbAlertCondition")
    def nb_alert_condition(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of alert condition
        """
        return pulumi.get(self, "nb_alert_condition")

    @nb_alert_condition.setter
    def nb_alert_condition(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_alert_condition", value)

    @property
    @pulumi.getter(name="nbArchive")
    def nb_archive(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of coldstored archivesr
        """
        return pulumi.get(self, "nb_archive")

    @nb_archive.setter
    def nb_archive(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_archive", value)

    @property
    @pulumi.getter(name="parentStreamId")
    def parent_stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Parent stream ID
        """
        return pulumi.get(self, "parent_stream_id")

    @parent_stream_id.setter
    def parent_stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_stream_id", value)

    @property
    @pulumi.getter(name="pauseIndexingOnMaxSize")
    def pause_indexing_on_max_size(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        If set, pause indexing when maximum size is reach
        """
        return pulumi.get(self, "pause_indexing_on_max_size")

    @pause_indexing_on_max_size.setter
    def pause_indexing_on_max_size(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pause_indexing_on_max_size", value)

    @property
    @pulumi.getter(name="retentionId")
    def retention_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Retention ID
        """
        return pulumi.get(self, "retention_id")

    @retention_id.setter
    def retention_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream ID
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stream_id", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream description
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream last updater
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="webSocketEnabled")
    def web_socket_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable Websocket
        """
        return pulumi.get(self, "web_socket_enabled")

    @web_socket_enabled.setter
    def web_socket_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "web_socket_enabled", value)

    @property
    @pulumi.getter(name="writeToken")
    def write_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Write token of the stream (empty if the caller is not the owner of the stream)
        """
        return pulumi.get(self, "write_token")

    @write_token.setter
    def write_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "write_token", value)


class LogsOutputGraylogStream(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cold_storage_compression: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_content: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_retention: Optional[pulumi.Input[builtins.int]] = None,
                 cold_storage_target: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 indexing_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 indexing_max_size: Optional[pulumi.Input[builtins.int]] = None,
                 indexing_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 parent_stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 pause_indexing_on_max_size: Optional[pulumi.Input[builtins.bool]] = None,
                 retention_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 web_socket_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        Creates a DBaaS Logs Graylog output stream.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        stream = ovh.dbaas.LogsOutputGraylogStream("stream",
            service_name="....",
            title="my stream",
            description="my graylog stream")
        ```

        To define the retention of the stream, you can use the following configuration:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        retention = ovh.Dbaas.get_logs_clusters_retention(service_name="ldp-xx-xxxxx",
            cluster_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            duration="P14D")
        stream = ovh.dbaas.LogsOutputGraylogStream("stream",
            service_name="....",
            title="my stream",
            description="my graylog stream",
            retention_id=retention.retention_id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cold_storage_compression: Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        :param pulumi.Input[builtins.str] cold_storage_content: ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        :param pulumi.Input[builtins.bool] cold_storage_enabled: Is Cold storage enabled?
        :param pulumi.Input[builtins.bool] cold_storage_notify_enabled: Notify on new Cold storage archive
        :param pulumi.Input[builtins.int] cold_storage_retention: Cold storage retention in year
        :param pulumi.Input[builtins.str] cold_storage_target: ColdStorage destination. One of "PCA", "PCS"
        :param pulumi.Input[builtins.str] description: Stream description
        :param pulumi.Input[builtins.bool] indexing_enabled: Enable ES indexing
        :param pulumi.Input[builtins.int] indexing_max_size: Maximum indexing size (in GB)
        :param pulumi.Input[builtins.bool] indexing_notify_enabled: If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        :param pulumi.Input[builtins.str] parent_stream_id: Parent stream ID
        :param pulumi.Input[builtins.bool] pause_indexing_on_max_size: If set, pause indexing when maximum size is reach
        :param pulumi.Input[builtins.str] retention_id: Retention ID
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] title: Stream description
        :param pulumi.Input[builtins.bool] web_socket_enabled: Enable Websocket
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogsOutputGraylogStreamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a DBaaS Logs Graylog output stream.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        stream = ovh.dbaas.LogsOutputGraylogStream("stream",
            service_name="....",
            title="my stream",
            description="my graylog stream")
        ```

        To define the retention of the stream, you can use the following configuration:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        retention = ovh.Dbaas.get_logs_clusters_retention(service_name="ldp-xx-xxxxx",
            cluster_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            duration="P14D")
        stream = ovh.dbaas.LogsOutputGraylogStream("stream",
            service_name="....",
            title="my stream",
            description="my graylog stream",
            retention_id=retention.retention_id)
        ```

        :param str resource_name: The name of the resource.
        :param LogsOutputGraylogStreamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogsOutputGraylogStreamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cold_storage_compression: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_content: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage_retention: Optional[pulumi.Input[builtins.int]] = None,
                 cold_storage_target: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 indexing_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 indexing_max_size: Optional[pulumi.Input[builtins.int]] = None,
                 indexing_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 parent_stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 pause_indexing_on_max_size: Optional[pulumi.Input[builtins.bool]] = None,
                 retention_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 web_socket_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogsOutputGraylogStreamArgs.__new__(LogsOutputGraylogStreamArgs)

            __props__.__dict__["cold_storage_compression"] = cold_storage_compression
            __props__.__dict__["cold_storage_content"] = cold_storage_content
            __props__.__dict__["cold_storage_enabled"] = cold_storage_enabled
            __props__.__dict__["cold_storage_notify_enabled"] = cold_storage_notify_enabled
            __props__.__dict__["cold_storage_retention"] = cold_storage_retention
            __props__.__dict__["cold_storage_target"] = cold_storage_target
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["indexing_enabled"] = indexing_enabled
            __props__.__dict__["indexing_max_size"] = indexing_max_size
            __props__.__dict__["indexing_notify_enabled"] = indexing_notify_enabled
            __props__.__dict__["parent_stream_id"] = parent_stream_id
            __props__.__dict__["pause_indexing_on_max_size"] = pause_indexing_on_max_size
            __props__.__dict__["retention_id"] = retention_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["web_socket_enabled"] = web_socket_enabled
            __props__.__dict__["can_alert"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["is_editable"] = None
            __props__.__dict__["is_shareable"] = None
            __props__.__dict__["nb_alert_condition"] = None
            __props__.__dict__["nb_archive"] = None
            __props__.__dict__["stream_id"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["write_token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["writeToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(LogsOutputGraylogStream, __self__).__init__(
            'ovh:Dbaas/logsOutputGraylogStream:LogsOutputGraylogStream',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_alert: Optional[pulumi.Input[builtins.bool]] = None,
            cold_storage_compression: Optional[pulumi.Input[builtins.str]] = None,
            cold_storage_content: Optional[pulumi.Input[builtins.str]] = None,
            cold_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            cold_storage_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            cold_storage_retention: Optional[pulumi.Input[builtins.int]] = None,
            cold_storage_target: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            indexing_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            indexing_max_size: Optional[pulumi.Input[builtins.int]] = None,
            indexing_notify_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            is_editable: Optional[pulumi.Input[builtins.bool]] = None,
            is_shareable: Optional[pulumi.Input[builtins.bool]] = None,
            nb_alert_condition: Optional[pulumi.Input[builtins.int]] = None,
            nb_archive: Optional[pulumi.Input[builtins.int]] = None,
            parent_stream_id: Optional[pulumi.Input[builtins.str]] = None,
            pause_indexing_on_max_size: Optional[pulumi.Input[builtins.bool]] = None,
            retention_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            stream_id: Optional[pulumi.Input[builtins.str]] = None,
            title: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            web_socket_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            write_token: Optional[pulumi.Input[builtins.str]] = None) -> 'LogsOutputGraylogStream':
        """
        Get an existing LogsOutputGraylogStream resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] can_alert: Indicates if the current user can create alert on the stream
        :param pulumi.Input[builtins.str] cold_storage_compression: Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        :param pulumi.Input[builtins.str] cold_storage_content: ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        :param pulumi.Input[builtins.bool] cold_storage_enabled: Is Cold storage enabled?
        :param pulumi.Input[builtins.bool] cold_storage_notify_enabled: Notify on new Cold storage archive
        :param pulumi.Input[builtins.int] cold_storage_retention: Cold storage retention in year
        :param pulumi.Input[builtins.str] cold_storage_target: ColdStorage destination. One of "PCA", "PCS"
        :param pulumi.Input[builtins.str] created_at: Stream creation
        :param pulumi.Input[builtins.str] description: Stream description
        :param pulumi.Input[builtins.bool] indexing_enabled: Enable ES indexing
        :param pulumi.Input[builtins.int] indexing_max_size: Maximum indexing size (in GB)
        :param pulumi.Input[builtins.bool] indexing_notify_enabled: If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        :param pulumi.Input[builtins.bool] is_editable: Indicates if you are allowed to edit entry
        :param pulumi.Input[builtins.bool] is_shareable: Indicates if you are allowed to share entry
        :param pulumi.Input[builtins.int] nb_alert_condition: Number of alert condition
        :param pulumi.Input[builtins.int] nb_archive: Number of coldstored archivesr
        :param pulumi.Input[builtins.str] parent_stream_id: Parent stream ID
        :param pulumi.Input[builtins.bool] pause_indexing_on_max_size: If set, pause indexing when maximum size is reach
        :param pulumi.Input[builtins.str] retention_id: Retention ID
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] stream_id: Stream ID
        :param pulumi.Input[builtins.str] title: Stream description
        :param pulumi.Input[builtins.str] updated_at: Stream last updater
        :param pulumi.Input[builtins.bool] web_socket_enabled: Enable Websocket
        :param pulumi.Input[builtins.str] write_token: Write token of the stream (empty if the caller is not the owner of the stream)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogsOutputGraylogStreamState.__new__(_LogsOutputGraylogStreamState)

        __props__.__dict__["can_alert"] = can_alert
        __props__.__dict__["cold_storage_compression"] = cold_storage_compression
        __props__.__dict__["cold_storage_content"] = cold_storage_content
        __props__.__dict__["cold_storage_enabled"] = cold_storage_enabled
        __props__.__dict__["cold_storage_notify_enabled"] = cold_storage_notify_enabled
        __props__.__dict__["cold_storage_retention"] = cold_storage_retention
        __props__.__dict__["cold_storage_target"] = cold_storage_target
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["indexing_enabled"] = indexing_enabled
        __props__.__dict__["indexing_max_size"] = indexing_max_size
        __props__.__dict__["indexing_notify_enabled"] = indexing_notify_enabled
        __props__.__dict__["is_editable"] = is_editable
        __props__.__dict__["is_shareable"] = is_shareable
        __props__.__dict__["nb_alert_condition"] = nb_alert_condition
        __props__.__dict__["nb_archive"] = nb_archive
        __props__.__dict__["parent_stream_id"] = parent_stream_id
        __props__.__dict__["pause_indexing_on_max_size"] = pause_indexing_on_max_size
        __props__.__dict__["retention_id"] = retention_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["stream_id"] = stream_id
        __props__.__dict__["title"] = title
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["web_socket_enabled"] = web_socket_enabled
        __props__.__dict__["write_token"] = write_token
        return LogsOutputGraylogStream(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canAlert")
    def can_alert(self) -> pulumi.Output[builtins.bool]:
        """
        Indicates if the current user can create alert on the stream
        """
        return pulumi.get(self, "can_alert")

    @property
    @pulumi.getter(name="coldStorageCompression")
    def cold_storage_compression(self) -> pulumi.Output[builtins.str]:
        """
        Cold storage compression method. One of "LZMA", "GZIP", "DEFLATED", "ZSTD"
        """
        return pulumi.get(self, "cold_storage_compression")

    @property
    @pulumi.getter(name="coldStorageContent")
    def cold_storage_content(self) -> pulumi.Output[builtins.str]:
        """
        ColdStorage content. One of "ALL", "GLEF", "PLAIN"
        """
        return pulumi.get(self, "cold_storage_content")

    @property
    @pulumi.getter(name="coldStorageEnabled")
    def cold_storage_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Is Cold storage enabled?
        """
        return pulumi.get(self, "cold_storage_enabled")

    @property
    @pulumi.getter(name="coldStorageNotifyEnabled")
    def cold_storage_notify_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Notify on new Cold storage archive
        """
        return pulumi.get(self, "cold_storage_notify_enabled")

    @property
    @pulumi.getter(name="coldStorageRetention")
    def cold_storage_retention(self) -> pulumi.Output[builtins.int]:
        """
        Cold storage retention in year
        """
        return pulumi.get(self, "cold_storage_retention")

    @property
    @pulumi.getter(name="coldStorageTarget")
    def cold_storage_target(self) -> pulumi.Output[builtins.str]:
        """
        ColdStorage destination. One of "PCA", "PCS"
        """
        return pulumi.get(self, "cold_storage_target")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Stream creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Stream description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="indexingEnabled")
    def indexing_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Enable ES indexing
        """
        return pulumi.get(self, "indexing_enabled")

    @property
    @pulumi.getter(name="indexingMaxSize")
    def indexing_max_size(self) -> pulumi.Output[builtins.int]:
        """
        Maximum indexing size (in GB)
        """
        return pulumi.get(self, "indexing_max_size")

    @property
    @pulumi.getter(name="indexingNotifyEnabled")
    def indexing_notify_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        """
        return pulumi.get(self, "indexing_notify_enabled")

    @property
    @pulumi.getter(name="isEditable")
    def is_editable(self) -> pulumi.Output[builtins.bool]:
        """
        Indicates if you are allowed to edit entry
        """
        return pulumi.get(self, "is_editable")

    @property
    @pulumi.getter(name="isShareable")
    def is_shareable(self) -> pulumi.Output[builtins.bool]:
        """
        Indicates if you are allowed to share entry
        """
        return pulumi.get(self, "is_shareable")

    @property
    @pulumi.getter(name="nbAlertCondition")
    def nb_alert_condition(self) -> pulumi.Output[builtins.int]:
        """
        Number of alert condition
        """
        return pulumi.get(self, "nb_alert_condition")

    @property
    @pulumi.getter(name="nbArchive")
    def nb_archive(self) -> pulumi.Output[builtins.int]:
        """
        Number of coldstored archivesr
        """
        return pulumi.get(self, "nb_archive")

    @property
    @pulumi.getter(name="parentStreamId")
    def parent_stream_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Parent stream ID
        """
        return pulumi.get(self, "parent_stream_id")

    @property
    @pulumi.getter(name="pauseIndexingOnMaxSize")
    def pause_indexing_on_max_size(self) -> pulumi.Output[builtins.bool]:
        """
        If set, pause indexing when maximum size is reach
        """
        return pulumi.get(self, "pause_indexing_on_max_size")

    @property
    @pulumi.getter(name="retentionId")
    def retention_id(self) -> pulumi.Output[builtins.str]:
        """
        Retention ID
        """
        return pulumi.get(self, "retention_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Output[builtins.str]:
        """
        Stream ID
        """
        return pulumi.get(self, "stream_id")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[builtins.str]:
        """
        Stream description
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Stream last updater
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="webSocketEnabled")
    def web_socket_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Enable Websocket
        """
        return pulumi.get(self, "web_socket_enabled")

    @property
    @pulumi.getter(name="writeToken")
    def write_token(self) -> pulumi.Output[builtins.str]:
        """
        Write token of the stream (empty if the caller is not the owner of the stream)
        """
        return pulumi.get(self, "write_token")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ContainerRegistryIPRestrictionsManagementArgs', 'ContainerRegistryIPRestrictionsManagement']

@pulumi.input_type
class ContainerRegistryIPRestrictionsManagementArgs:
    def __init__(__self__, *,
                 ip_restrictions: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]],
                 registry_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a ContainerRegistryIPRestrictionsManagement resource.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]] ip_restrictions: IP restrictions applied on Harbor UI and API.
        :param pulumi.Input[builtins.str] registry_id: The id of the Managed Private Registry.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "ip_restrictions", ip_restrictions)
        pulumi.set(__self__, "registry_id", registry_id)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="ipRestrictions")
    def ip_restrictions(self) -> pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]:
        """
        IP restrictions applied on Harbor UI and API.
        """
        return pulumi.get(self, "ip_restrictions")

    @ip_restrictions.setter
    def ip_restrictions(self, value: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]):
        pulumi.set(self, "ip_restrictions", value)

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the Managed Private Registry.
        """
        return pulumi.get(self, "registry_id")

    @registry_id.setter
    def registry_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "registry_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _ContainerRegistryIPRestrictionsManagementState:
    def __init__(__self__, *,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ContainerRegistryIPRestrictionsManagement resources.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]] ip_restrictions: IP restrictions applied on Harbor UI and API.
        :param pulumi.Input[builtins.str] registry_id: The id of the Managed Private Registry.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        if ip_restrictions is not None:
            pulumi.set(__self__, "ip_restrictions", ip_restrictions)
        if registry_id is not None:
            pulumi.set(__self__, "registry_id", registry_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="ipRestrictions")
    def ip_restrictions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]]:
        """
        IP restrictions applied on Harbor UI and API.
        """
        return pulumi.get(self, "ip_restrictions")

    @ip_restrictions.setter
    def ip_restrictions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]]):
        pulumi.set(self, "ip_restrictions", value)

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the Managed Private Registry.
        """
        return pulumi.get(self, "registry_id")

    @registry_id.setter
    def registry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "registry_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


class ContainerRegistryIPRestrictionsManagement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Apply IP restrictions container registry associated with a public cloud project on Harbor UI and API.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        registry = ovh.CloudProject.get_container_registry(service_name="XXXXXX",
            registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
        my_mgt_iprestrictions = ovh.cloud_project.ContainerRegistryIPRestrictionsManagement("my_mgt_iprestrictions",
            service_name=registry_ovh_cloud_project_containerregistry["serviceName"],
            registry_id=registry_ovh_cloud_project_containerregistry["id"],
            ip_restrictions=[{
                "ip_block": "xxx.xxx.xxx.xxx/xx",
                "description": "xxxxxxx",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]] ip_restrictions: IP restrictions applied on Harbor UI and API.
        :param pulumi.Input[builtins.str] registry_id: The id of the Managed Private Registry.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContainerRegistryIPRestrictionsManagementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Apply IP restrictions container registry associated with a public cloud project on Harbor UI and API.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        registry = ovh.CloudProject.get_container_registry(service_name="XXXXXX",
            registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
        my_mgt_iprestrictions = ovh.cloud_project.ContainerRegistryIPRestrictionsManagement("my_mgt_iprestrictions",
            service_name=registry_ovh_cloud_project_containerregistry["serviceName"],
            registry_id=registry_ovh_cloud_project_containerregistry["id"],
            ip_restrictions=[{
                "ip_block": "xxx.xxx.xxx.xxx/xx",
                "description": "xxxxxxx",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param ContainerRegistryIPRestrictionsManagementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContainerRegistryIPRestrictionsManagementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContainerRegistryIPRestrictionsManagementArgs.__new__(ContainerRegistryIPRestrictionsManagementArgs)

            if ip_restrictions is None and not opts.urn:
                raise TypeError("Missing required property 'ip_restrictions'")
            __props__.__dict__["ip_restrictions"] = ip_restrictions
            if registry_id is None and not opts.urn:
                raise TypeError("Missing required property 'registry_id'")
            __props__.__dict__["registry_id"] = registry_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
        super(ContainerRegistryIPRestrictionsManagement, __self__).__init__(
            'ovh:CloudProject/containerRegistryIPRestrictionsManagement:ContainerRegistryIPRestrictionsManagement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]]] = None,
            registry_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'ContainerRegistryIPRestrictionsManagement':
        """
        Get an existing ContainerRegistryIPRestrictionsManagement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]] ip_restrictions: IP restrictions applied on Harbor UI and API.
        :param pulumi.Input[builtins.str] registry_id: The id of the Managed Private Registry.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContainerRegistryIPRestrictionsManagementState.__new__(_ContainerRegistryIPRestrictionsManagementState)

        __props__.__dict__["ip_restrictions"] = ip_restrictions
        __props__.__dict__["registry_id"] = registry_id
        __props__.__dict__["service_name"] = service_name
        return ContainerRegistryIPRestrictionsManagement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="ipRestrictions")
    def ip_restrictions(self) -> pulumi.Output[Sequence[Mapping[str, builtins.str]]]:
        """
        IP restrictions applied on Harbor UI and API.
        """
        return pulumi.get(self, "ip_restrictions")

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the Managed Private Registry.
        """
        return pulumi.get(self, "registry_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetKafkaSchemaRegistryAclsResult',
    'AwaitableGetKafkaSchemaRegistryAclsResult',
    'get_kafka_schema_registry_acls',
    'get_kafka_schema_registry_acls_output',
]

@pulumi.output_type
class GetKafkaSchemaRegistryAclsResult:
    """
    A collection of values returned by getKafkaSchemaRegistryAcls.
    """
    def __init__(__self__, acl_ids=None, cluster_id=None, id=None, service_name=None):
        if acl_ids and not isinstance(acl_ids, list):
            raise TypeError("Expected argument 'acl_ids' to be a list")
        pulumi.set(__self__, "acl_ids", acl_ids)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="aclIds")
    def acl_ids(self) -> Sequence[builtins.str]:
        """
        The list of schema refistry ACLs ids of the kafka cluster associated with the project.
        """
        return pulumi.get(self, "acl_ids")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")


class AwaitableGetKafkaSchemaRegistryAclsResult(GetKafkaSchemaRegistryAclsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKafkaSchemaRegistryAclsResult(
            acl_ids=self.acl_ids,
            cluster_id=self.cluster_id,
            id=self.id,
            service_name=self.service_name)


def get_kafka_schema_registry_acls(cluster_id: Optional[builtins.str] = None,
                                   service_name: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKafkaSchemaRegistryAclsResult:
    """
    Use this data source to get the list of ACLs of a kafka cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    schema_registry_acls = ovh.CloudProjectDatabase.get_kafka_schema_registry_acls(service_name="XXX",
        cluster_id="YYY")
    pulumi.export("aclIds", schema_registry_acls.acl_ids)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getKafkaSchemaRegistryAcls:getKafkaSchemaRegistryAcls', __args__, opts=opts, typ=GetKafkaSchemaRegistryAclsResult).value

    return AwaitableGetKafkaSchemaRegistryAclsResult(
        acl_ids=pulumi.get(__ret__, 'acl_ids'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_kafka_schema_registry_acls_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                                          service_name: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKafkaSchemaRegistryAclsResult]:
    """
    Use this data source to get the list of ACLs of a kafka cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    schema_registry_acls = ovh.CloudProjectDatabase.get_kafka_schema_registry_acls(service_name="XXX",
        cluster_id="YYY")
    pulumi.export("aclIds", schema_registry_acls.acl_ids)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getKafkaSchemaRegistryAcls:getKafkaSchemaRegistryAcls', __args__, opts=opts, typ=GetKafkaSchemaRegistryAclsResult)
    return __ret__.apply(lambda __response__: GetKafkaSchemaRegistryAclsResult(
        acl_ids=pulumi.get(__response__, 'acl_ids'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetZoneDNSSecResult',
    'AwaitableGetZoneDNSSecResult',
    'get_zone_dns_sec',
    'get_zone_dns_sec_output',
]

@pulumi.output_type
class GetZoneDNSSecResult:
    """
    A collection of values returned by getZoneDNSSec.
    """
    def __init__(__self__, id=None, status=None, zone_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if zone_name and not isinstance(zone_name, str):
            raise TypeError("Expected argument 'zone_name' to be a str")
        pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        DNSSEC status (`disableInProgress`, `disabled`, `enableInProgress` or `enabled`)
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> builtins.str:
        return pulumi.get(self, "zone_name")


class AwaitableGetZoneDNSSecResult(GetZoneDNSSecResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetZoneDNSSecResult(
            id=self.id,
            status=self.status,
            zone_name=self.zone_name)


def get_zone_dns_sec(zone_name: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetZoneDNSSecResult:
    """
    Use this data source to retrieve information about a domain zone DNSSEC status.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    dnssec = ovh.Domain.get_zone_dns_sec(zone_name="mysite.ovh")
    ```


    :param builtins.str zone_name: The name of the domain zone
    """
    __args__ = dict()
    __args__['zoneName'] = zone_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Domain/getZoneDNSSec:getZoneDNSSec', __args__, opts=opts, typ=GetZoneDNSSecResult).value

    return AwaitableGetZoneDNSSecResult(
        id=pulumi.get(__ret__, 'id'),
        status=pulumi.get(__ret__, 'status'),
        zone_name=pulumi.get(__ret__, 'zone_name'))
def get_zone_dns_sec_output(zone_name: Optional[pulumi.Input[builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetZoneDNSSecResult]:
    """
    Use this data source to retrieve information about a domain zone DNSSEC status.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    dnssec = ovh.Domain.get_zone_dns_sec(zone_name="mysite.ovh")
    ```


    :param builtins.str zone_name: The name of the domain zone
    """
    __args__ = dict()
    __args__['zoneName'] = zone_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Domain/getZoneDNSSec:getZoneDNSSec', __args__, opts=opts, typ=GetZoneDNSSecResult)
    return __ret__.apply(lambda __response__: GetZoneDNSSecResult(
        id=pulumi.get(__response__, 'id'),
        status=pulumi.get(__response__, 'status'),
        zone_name=pulumi.get(__response__, 'zone_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['KubeIpRestrictionsArgs', 'KubeIpRestrictions']

@pulumi.input_type
class KubeIpRestrictionsArgs:
    def __init__(__self__, *,
                 ips: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 kube_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a KubeIpRestrictions resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ips: List of CIDR authorized to interact with the managed Kubernetes cluster.
        :param pulumi.Input[builtins.str] kube_id: The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        pulumi.set(__self__, "ips", ips)
        pulumi.set(__self__, "kube_id", kube_id)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def ips(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        List of CIDR authorized to interact with the managed Kubernetes cluster.
        """
        return pulumi.get(self, "ips")

    @ips.setter
    def ips(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "ips", value)

    @property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kube_id")

    @kube_id.setter
    def kube_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "kube_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _KubeIpRestrictionsState:
    def __init__(__self__, *,
                 ips: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 kube_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering KubeIpRestrictions resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ips: List of CIDR authorized to interact with the managed Kubernetes cluster.
        :param pulumi.Input[builtins.str] kube_id: The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        if ips is not None:
            pulumi.set(__self__, "ips", ips)
        if kube_id is not None:
            pulumi.set(__self__, "kube_id", kube_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of CIDR authorized to interact with the managed Kubernetes cluster.
        """
        return pulumi.get(self, "ips")

    @ips.setter
    def ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ips", value)

    @property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kube_id")

    @kube_id.setter
    def kube_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kube_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


class KubeIpRestrictions(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ips: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 kube_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Apply IP restrictions to an OVHcloud Managed Kubernetes cluster.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        vrack_only = ovh.cloud_project.KubeIpRestrictions("vrack_only",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx",
            ips=["10.42.0.0/16"])
        ```

        ## Import

        OVHcloud Managed Kubernetes Service cluster IP restrictions can be imported using the `service_name` and the `id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/kubeIpRestrictions:KubeIpRestrictions iprestrictions service_name/kube_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ips: List of CIDR authorized to interact with the managed Kubernetes cluster.
        :param pulumi.Input[builtins.str] kube_id: The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubeIpRestrictionsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Apply IP restrictions to an OVHcloud Managed Kubernetes cluster.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        vrack_only = ovh.cloud_project.KubeIpRestrictions("vrack_only",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx",
            ips=["10.42.0.0/16"])
        ```

        ## Import

        OVHcloud Managed Kubernetes Service cluster IP restrictions can be imported using the `service_name` and the `id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/kubeIpRestrictions:KubeIpRestrictions iprestrictions service_name/kube_id
        ```

        :param str resource_name: The name of the resource.
        :param KubeIpRestrictionsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubeIpRestrictionsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ips: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 kube_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubeIpRestrictionsArgs.__new__(KubeIpRestrictionsArgs)

            if ips is None and not opts.urn:
                raise TypeError("Missing required property 'ips'")
            __props__.__dict__["ips"] = ips
            if kube_id is None and not opts.urn:
                raise TypeError("Missing required property 'kube_id'")
            __props__.__dict__["kube_id"] = kube_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
        super(KubeIpRestrictions, __self__).__init__(
            'ovh:CloudProject/kubeIpRestrictions:KubeIpRestrictions',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ips: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            kube_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'KubeIpRestrictions':
        """
        Get an existing KubeIpRestrictions resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ips: List of CIDR authorized to interact with the managed Kubernetes cluster.
        :param pulumi.Input[builtins.str] kube_id: The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KubeIpRestrictionsState.__new__(_KubeIpRestrictionsState)

        __props__.__dict__["ips"] = ips
        __props__.__dict__["kube_id"] = kube_id
        __props__.__dict__["service_name"] = service_name
        return KubeIpRestrictions(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def ips(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of CIDR authorized to interact with the managed Kubernetes cluster.
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the managed Kubernetes cluster. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kube_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

